@@ -8,14 +8,6 @@ has [qw(key value)] => (
 
 no Any::Moose;
 __PACKAGE__->meta->make_immutable();
-
-package
-    Text::Xslate::Type::Pair;
-use Any::Moose;
-extends 'Text::Xslate::PP::Type::Pair';
-no Any::Moose;
-__PACKAGE__->meta->make_immutable();
-
 __END__
 
 =head1 NAME
