@@ -1,5 +1,5 @@
 package Text::Xslate::Syntax::Foo;
-use Mouse;
+use Any::Moose;
 
 extends qw(Text::Xslate::Parser);
 
@@ -7,6 +7,6 @@ sub _build_line_start { undef }
 sub _build_tag_start  { '<%'  }
 sub _build_tag_end    { '%>'  }
 
-no Mouse;
+no Any::Moose;
 
 __PACKAGE__->meta->make_immutable();
