@@ -202,10 +202,16 @@ tx_sv_is_array_ref(pTHX_ SV* const sv);
 int
 tx_sv_is_hash_ref(pTHX_ SV* const sv);
 
+int
+tx_sv_is_code_ref(pTHX_ SV* const sv);
+
 /* builtin method stuff */
 
 SV*
 tx_methodcall(pTHX_ tx_state_t* const st, SV* const method);
 
+SV*
+tx_merge_hash(pTHX_ tx_state_t* const st, SV* base, SV* value);
+
 void
 tx_register_builtin_methods(pTHX_ HV* const hv);
